Discover Packages
github.com/evilsocket/arc
arcd
app
package
Version:
v1.0.9
Opens a new window with list of versions in this module.
Published: Dec 19, 2017
License: GPL-3.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
* Arc - Copyleft of Simone 'evilsocket' Margaritelli.
* evilsocket at protonmail dot com
* https://www.evilsocket.net/
*
* See LICENSE.
type Author struct {
Name string `json:"name"`
Email string `json:"email"`
License string `json:"license"`
}
Information about the author of the web application.
type Manifest struct {
Name string `json:"name"`
Description string `json:"description"`
Version string `json:"version"`
Author Author `json:"author"`
Index string `json:"index"`
}
Information about the web application.
swagger:response
Source Files
¶
Click to show internal directories.
Click to hide internal directories.